package org.acme.spring.data.jpa;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
class FruitResourceIT extends FruitResourceTest {

}
